📓 Examples and Tutorials
=========================

Here you can find practical examples demonstrating how to use **Fracnetics**.

**CartPole Tutorial**

.. image:: https://colab.research.google.com/assets/colab-badge.svg
   :target: https://colab.research.google.com/github/FabianKoehnke/fracnetics/blob/main/notebooks/minExampleCartPole.ipynb
   :alt: Open in Colab
   :align: center

This notebook demonstrates how Fracnetics can control the CartPole environment from *Gymnasium* (a fork of OpenAI Gym).

**Iris Classification Tutorial**

.. image:: https://colab.research.google.com/assets/colab-badge.svg
   :target: https://colab.research.google.com/github/FabianKoehnke/fracnetics/blob/main/notebooks/minExampleIRIS.ipynb
   :alt: Open in Colab
   :align: center

This notebook demonstrates how Fracnetics can evolve interpretable decision structures for simple classification tasks.

